@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_kinesisanalytics.type_defs import (
     ApplicationUpdateTypeDef,
@@ -38,24 +38,24 @@ __all__ = ("KinesisAnalyticsClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    CodeValidationException: Boto3ClientError
-    ConcurrentModificationException: Boto3ClientError
-    InvalidApplicationConfigurationException: Boto3ClientError
-    InvalidArgumentException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    ResourceInUseException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ResourceProvisionedThroughputExceededException: Boto3ClientError
-    ServiceUnavailableException: Boto3ClientError
-    TooManyTagsException: Boto3ClientError
-    UnableToDetectSchemaException: Boto3ClientError
-    UnsupportedOperationException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    CodeValidationException: Type[Boto3ClientError]
+    ConcurrentModificationException: Type[Boto3ClientError]
+    InvalidApplicationConfigurationException: Type[Boto3ClientError]
+    InvalidArgumentException: Type[Boto3ClientError]
+    LimitExceededException: Type[Boto3ClientError]
+    ResourceInUseException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ResourceProvisionedThroughputExceededException: Type[Boto3ClientError]
+    ServiceUnavailableException: Type[Boto3ClientError]
+    TooManyTagsException: Type[Boto3ClientError]
+    UnableToDetectSchemaException: Type[Boto3ClientError]
+    UnsupportedOperationException: Type[Boto3ClientError]
 
 
 class KinesisAnalyticsClient:
     """
-    [KinesisAnalytics.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
+    [KinesisAnalytics.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
     """
 
     exceptions: Exceptions
@@ -67,14 +67,14 @@ class KinesisAnalyticsClient:
         CloudWatchLoggingOption: CloudWatchLoggingOptionTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.add_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
+        [Client.add_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
         """
 
     def add_application_input(
         self, ApplicationName: str, CurrentApplicationVersionId: int, Input: InputTypeDef
     ) -> Dict[str, Any]:
         """
-        [Client.add_application_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
+        [Client.add_application_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
         """
 
     def add_application_input_processing_configuration(
@@ -85,14 +85,14 @@ class KinesisAnalyticsClient:
         InputProcessingConfiguration: InputProcessingConfigurationTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.add_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
+        [Client.add_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
         """
 
     def add_application_output(
         self, ApplicationName: str, CurrentApplicationVersionId: int, Output: OutputTypeDef
     ) -> Dict[str, Any]:
         """
-        [Client.add_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
+        [Client.add_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
         """
 
     def add_application_reference_data_source(
@@ -102,12 +102,12 @@ class KinesisAnalyticsClient:
         ReferenceDataSource: ReferenceDataSourceTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.add_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
+        [Client.add_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
         """
 
     def create_application(
@@ -121,45 +121,45 @@ class KinesisAnalyticsClient:
         Tags: List[TagTypeDef] = None,
     ) -> CreateApplicationResponseTypeDef:
         """
-        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
+        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
         """
 
     def delete_application(self, ApplicationName: str, CreateTimestamp: datetime) -> Dict[str, Any]:
         """
-        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
+        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
         """
 
     def delete_application_cloud_watch_logging_option(
         self, ApplicationName: str, CurrentApplicationVersionId: int, CloudWatchLoggingOptionId: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
+        [Client.delete_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
         """
 
     def delete_application_input_processing_configuration(
         self, ApplicationName: str, CurrentApplicationVersionId: int, InputId: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
+        [Client.delete_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
         """
 
     def delete_application_output(
         self, ApplicationName: str, CurrentApplicationVersionId: int, OutputId: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
+        [Client.delete_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
         """
 
     def delete_application_reference_data_source(
         self, ApplicationName: str, CurrentApplicationVersionId: int, ReferenceId: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
+        [Client.delete_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
         """
 
     def describe_application(self, ApplicationName: str) -> DescribeApplicationResponseTypeDef:
         """
-        [Client.describe_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
+        [Client.describe_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
         """
 
     def discover_input_schema(
@@ -171,7 +171,7 @@ class KinesisAnalyticsClient:
         InputProcessingConfiguration: InputProcessingConfigurationTypeDef = None,
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
-        [Client.discover_input_schema documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
+        [Client.discover_input_schema documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
         """
 
     def generate_presigned_url(
@@ -182,41 +182,41 @@ class KinesisAnalyticsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
         """
 
     def list_applications(
         self, Limit: int = None, ExclusiveStartApplicationName: str = None
     ) -> ListApplicationsResponseTypeDef:
         """
-        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
+        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
         """
 
     def list_tags_for_resource(self, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
         """
 
     def start_application(
         self, ApplicationName: str, InputConfigurations: List[InputConfigurationTypeDef]
     ) -> Dict[str, Any]:
         """
-        [Client.start_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
+        [Client.start_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
         """
 
     def stop_application(self, ApplicationName: str) -> Dict[str, Any]:
         """
-        [Client.stop_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
+        [Client.stop_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
         """
 
     def tag_resource(self, ResourceARN: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
         """
 
     def update_application(
@@ -226,5 +226,5 @@ class KinesisAnalyticsClient:
         ApplicationUpdate: ApplicationUpdateTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
+        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
         """
